print("""import pandas as pd
import matplotlib.pyplot as plt

churn_df = pd.read_csv('telecom_customer_churn.csv')
churn_df.head()

churn_df.info()

columns = churn_df.columns

def get_sample(df,columns):

    result = {}
    for col in columns:
        result[col] = df[col][:5]

    return result

get_sample(churn_df,columns)

import numpy as np
churn_df.replace(' ',np.nan,inplace=True)
churn_df.replace('?',np.nan,inplace=True)

churn_df.isna().sum()

churn_df['TotalCharges'] = pd.to_numeric(churn_df['TotalCharges'])
churn_df['TotalCharges'].fillna(churn_df['TotalCharges'].mean(),inplace=True)

numeric_col = []

for col in columns:
    if churn_df[col].dtype in ['int64' ,'float64']:
        numeric_col.append(col)

numeric_col = numeric_col[1:]
numeric_col

def show_outliers(df,columns):
    plt.figure(figsize=(10,6 * len(columns)))

    for i,col in enumerate(columns):
        plt.subplot(len(columns),1,i+1)
        plt.boxplot(df[col])
        plt.title(f'boxplot of {col}')
        plt.xlabel(col)

    plt.tight_layout()
    plt.show()

show_outliers(churn_df,numeric_col)

churn_df['Tenure_years'] = churn_df['tenure'] / 12
churn_df['avg_charges_per_month'] = churn_df['TotalCharges'] / churn_df['tenure']

from sklearn.model_selection import train_test_split

columns = churn_df.columns

numeric_columns = []

for col in columns:
    if churn_df[col].dtype in ['int64','float64']:
        numeric_columns.append(col)

numeric_columns

churn_df.drop(columns='customerID',inplace=True)
columns = churn_df.columns


cat_columns = [col for col in columns if col not in numeric_columns]
cat_columns

from sklearn.preprocessing import LabelEncoder

X = churn_df.drop(columns='Churn')
y = churn_df['Churn']

label = LabelEncoder()

for col in cat_columns[:-1]:
    X[col] = label.fit_transform(X[col])

X_train,X_test,y_train,y_test = train_test_split(X,y,test_size=0.3)


churn_df.to_csv('filtered.csv',index=False)""")


print("""import pandas as pd

uber_df = pd.read_csv('uber.csv')
uber_df.head()

uber_df.drop(columns='Unnamed: 0',inplace=True)
uber_df.isna().sum()
uber_df.dropna(inplace=True)

lat_to_km = 111
long_to_km = 85

uber_df['manhatten_distance'] = (uber_df['pickup_latitude'] - uber_df['dropoff_latitude']).abs() * lat_to_km + (uber_df['pickup_longitude'] - uber_df['dropoff_longitude']).abs() * long_to_km

uber_df['key'] = pd.to_datetime(uber_df['key'])
uber_df['weekday'] = uber_df['key'].dt.weekday
uber_df['hour'] = uber_df['key'].dt.hour
uber_df.describe()
uber_df = uber_df[uber_df['fare_amount']>0]
uber_df.shape

import matplotlib.pyplot as plt
import seaborn as sns
def uber_boxplot(df_column):

    plt.figure(figsize=(10,6))
    plt.subplot(3,1,1)
    sns.boxplot(uber_df[df_column])
    plt.ylabel(df_column)

    plt.show()


for i in ['fare_amount','passenger_count','manhatten_distance']:
    uber_boxplot(i)

columns_needed = ['fare_amount','passenger_count','manhatten_distance']

def remove_outliers(df,columns):

    for col in columns:
        q1 = df[col].quantile(0.25)
        q3 = df[col].quantile(0.75)

        iqr = q3 - q1

        lower_bound = q1 - 1.5 * iqr
        upper_bound = q3 + 1.5 * iqr

        fil_df = df[(df[col]>=lower_bound) & (df[col]<=upper_bound)]

    return fil_df
filtered_df = remove_outliers(uber_df,columns_needed)
filtered_df.shape

X = filtered_df[['pickup_longitude',
       'pickup_latitude', 'dropoff_longitude', 'dropoff_latitude',
       'passenger_count', 'manhatten_distance', 'weekday', 'hour']]

y = filtered_df['fare_amount']

from sklearn.linear_model import LinearRegression,Ridge,Lasso
from sklearn.preprocessing import StandardScaler
from sklearn.metrics import mean_squared_error,mean_absolute_error
from sklearn.model_selection import train_test_split

scaler = StandardScaler()
X_scaled = scaler.fit_transform(X)

X_train,X_test,y_train,y_test = train_test_split(X_scaled,y,test_size=0.2)

linear_model = LinearRegression()
linear_model.fit(X_train,y_train)

y_pred = linear_model.predict(X_test)

print(mean_squared_error(y_test,y_pred))
mean_absolute_error(y_test,y_pred)

ridge_model = Ridge(alpha=1)
ridge_model.fit(X_train,y_train)

y_pred = ridge_model.predict(X_test)

print(mean_squared_error(y_test,y_pred))
mean_absolute_error(y_test,y_pred)

lasso_model = Lasso(alpha=1)
lasso_model.fit(X_train,y_train)

y_pred = lasso_model.predict(X_test)

print(mean_squared_error(y_test,y_pred))
mean_absolute_error(y_test,y_pred)""")




print("""df = pd.read_csv('Iris.csv')
df.head()

classes = df['Species'].unique().tolist()
classes 
labels = [0,1,2]
df['Species'].replace(classes,labels,inplace=True)

df['Species'].unique()

df.head()

from sklearn.preprocessing import StandardScaler
from sklearn.discriminant_analysis import LinearDiscriminantAnalysis
import matplotlib.pyplot as plt
from sklearn.model_selection import train_test_split
from sklearn.metrics import accuracy_score

scaler = StandardScaler()
target_column = 'Species'

X = df.drop(columns=[target_column,'Id'])
y = df[target_column]

X_scaled = scaler.fit_transform(X)
X.shape
X_train,X_test,y_train,y_test = train_test_split(X_scaled,y,test_size=0.3)

lda = LinearDiscriminantAnalysis()
lda.fit(X_train,y_train)


y_pred = lda.predict(X_test)
accuracy_score(y_test,y_pred)


import numpy as np
sample = [3.0,2.3,5.5,0.7]

sample = scaler.transform(np.array([sample]))

sample_pred = lda.predict(sample)

classes[sample_pred.tolist()[0]]""")



print("""import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.ensemble import GradientBoostingClassifier,AdaBoostClassifier
from sklearn.metrics import accuracy_score,r2_score,precision_score

from xgboost import XGBClassifier

iris_df = pd.read_csv('Iris.csv')
iris_df.drop(columns='Id',inplace=True)
iris_df.head()

classes = iris_df['Species'].unique().tolist()
label = [0,1,2]

iris_df['Species'].replace(classes,label,inplace=True)
iris_df.head()

X = iris_df.drop(columns='Species')
y = iris_df['Species']

X_train,X_test,y_train,y_test = train_test_split(X,y,test_size=0.3)

ada_model = AdaBoostClassifier(n_estimators=200)
ada_model.fit(X_train,y_train)


y_pred = ada_model.predict(X_test)

accuracy_score(y_test,y_pred)

gra_model = GradientBoostingClassifier(n_estimators=200)

gra_model.fit(X_train,y_train)

y_pred = gra_model.predict(X_test)

accuracy_score(y_test,y_pred)

xg_model = XGBClassifier(n_estimators=200)

xg_model.fit(X_train,y_train)

y_pred = xg_model.predict(X_test)

accuracy_score(y_test,y_pred)""")



print("""import pandas as pd
from sklearn.ensemble import RandomForestClassifier
from sklearn.metrics import accuracy_score,ConfusionMatrixDisplay,confusion_matrix
from sklearn.preprocessing import LabelEncoder

car_df = pd.read_csv('car_evaluation.csv')
car_df.columns = ['buying_price','maintenance_cost','number_of_doors','number_of_persons','lug_boot','safety','decision']
car_df.head()

car_df.shape

columns = car_df.columns
columns

def unique_values(df,columns):

    results = {}
    for col in columns:
        results[col] = df[col].unique()


    return results

unique_values(car_df,columns)

label_encoder = LabelEncoder()

for col in columns:
    car_df[col] = label_encoder.fit_transform(car_df[col])

car_df.info()

target_column  = 'decision'

X = car_df.drop(columns=target_column)
y = car_df[target_column]

from sklearn.model_selection import train_test_split
X_train,X_test,y_train,y_test = train_test_split(X,y,test_size=0.3)

model = RandomForestClassifier(n_estimators=10000)

model.fit(X_train,y_train)

y_pred = model.predict(X_test)

accuracy_score(y_test,y_pred)""")






print("""import numpy as np
import random

# Define the maze environment
maze = np.array([
    [0, 0, 0, 0, 1],
    [1, 1, 0, 1, 0],
    [0, 0, 0, 0, 0],
    [0, 1, 1, 1, 0],
    [0, 0, 0, 0, 0]
])

# Parameters
start = (0, 0)
goal = (4, 4)
actions = ["up", "down", "left", "right"]
action_dict = {"up": (-1, 0), "down": (1, 0), "left": (0, -1), "right": (0, 1)}

# Hyperparameters
alpha = 0.1      # Learning rate
gamma = 0.9      # Discount factor
epsilon = 0.1    # Exploration rate
episodes = 5000

# Q-table initialization
q_table = np.zeros((maze.shape[0], maze.shape[1], len(actions)))

# Helper functions
def is_valid_move(state):
    x, y = state
    return 0 <= x < maze.shape[0] and 0 <= y < maze.shape[1] and maze[x, y] == 0

def get_next_state(state, action):
    x, y = state
    dx, dy = action_dict[action]
    next_state = (x + dx, y + dy)
    return next_state if is_valid_move(next_state) else state

def get_reward(state):
    return 100 if state == goal else -1

# Training loop
for episode in range(episodes):
    state = start
    done = False
    while not done:
        # Epsilon-greedy action selection
        if random.uniform(0, 1) < epsilon:
            action_index = random.choice(range(len(actions)))  # Explore
        else:
            action_index = np.argmax(q_table[state[0], state[1]])  # Exploit
        action = actions[action_index]
        
        # Take action and observe result
        next_state = get_next_state(state, action)
        reward = get_reward(next_state)
        
        # Update Q-value using the Q-learning formula
        best_next_action = np.argmax(q_table[next_state[0], next_state[1]])
        q_table[state[0], state[1], action_index] += alpha * (
            reward + gamma * q_table[next_state[0], next_state[1], best_next_action] -
            q_table[state[0], state[1], action_index]
        )
        
        # Transition to the next state
        state = next_state
        
        # Check if goal is reached
        if state == goal:
            done = True

# Print the Q-values for each state
print("Q-Table after training:")
print(q_table)

# Test the agent
def test_agent(start):
    state = start
    path = [state]
    while state != goal:
        action_index = np.argmax(q_table[state[0], state[1]])
        action = actions[action_index]
        state = get_next_state(state, action)
        path.append(state)
    return path

# Display path
print("Path taken by the agent from start to goal:")
print(test_agent(start))""")



print("""import pandas as pd

sales_df = pd.read_csv('sales_data_sample.csv',encoding='unicode_escape')
sales_df.head()

sales_df.to_json('sales.json')

sales_json_file = pd.read_json('sales.json')
sales_json_file.head()

sales_df.to_excel('sales.xlsx',index=False)

sales_excel_file = pd.read_excel('sales.xlsx')
sales_excel_file.head()

sales_df.drop(columns=['ADDRESSLINE2','STATE'],inplace=True)

sales_df['COUNTRY'].value_counts()

x = sales_df[pd.isna(sales_df['TERRITORY'])]['COUNTRY']
set(x)

label = 'AMERICAS'
import numpy as np
sales_df['TERRITORY'].replace(np.nan,label,inplace=True)

sales_df['TERRITORY'].unique()

sales_df.dropna(inplace=True)

import seaborn as sns 
import matplotlib.pyplot as plt

plt.figure(figsize=(10,6))
sns.lineplot(y=sales_df['SALES'],x = sales_df['YEAR_ID'])
plt.show()

sns.barplot(x =sales_df['YEAR_ID'],y=sales_df['SALES'])

top_cus = sales_df['CUSTOMERNAME'].value_counts()

plt.figure(figsize=(10,6))
top_cus[:5].plot(kind='bar', color='skyblue')
plt.show()

x = sales_df.groupby('YEAR_ID')['QUANTITYORDERED'].agg(['mean', 'min', 'max'])
x

x.plot(kind='bar', figsize=(10, 6))
plt.xlabel('Year')
plt.ylabel('Value')
plt.xticks(rotation=0)
plt.legend(title='Statistics')
plt.show()""")





print("""import pandas as pd
df = pd.read_csv('Wine.csv')
df.head()
df['Customer_Segment'].unique()
df.columns
df.isna().sum()
target_column = 'Customer_Segment'

X = df.drop(columns=target_column)
y = df[target_column]

from sklearn.decomposition import PCA
import matplotlib.pyplot as plt
from sklearn.preprocessing import StandardScaler
scaler = StandardScaler()
X_scaled = scaler.fit_transform(X)

pca = PCA()
pca.fit(X_scaled)
exp_var_ratio = pca.explained_variance_ratio_
cumulative_var = exp_var_ratio.cumsum()


plt.plot(range(1,len(cumulative_var)+1),cumulative_var,marker='o')
plt.xlabel('no of components')
plt.ylabel('var ')
plt.grid(True)

pca_new = PCA(n_components=8)
X_pca = pca_new.fit_transform(X_scaled)
plt.scatter(X_pca[:,0],X_pca[:,1],c=y)""")




print("""import matplotlib.pyplot as plt
from sklearn.svm import SVC
from sklearn import datasets

digits = datasets.load_digits()
from sklearn.model_selection import train_test_split
from sklearn.preprocessing import StandardScaler

X = digits.data
y = digits.target

plt.imshow(digits.images[1],cmap='gray')
X[:2]
set(y)

scaler = StandardScaler()
X_scaled = scaler.fit_transform(X)

X_train,X_test,y_train,y_test = train_test_split(X_scaled,y,test_size=0.3)

from sklearn.metrics import accuracy_score,classification_report,confusion_matrix,ConfusionMatrixDisplay


svm = SVC(kernel='rbf')

svm.fit(X_train,y_train)

y_pred = svm.predict(X_test)

accuracy_score(y_test,y_pred)

cm = confusion_matrix(y_test,y_pred)

c_mat = ConfusionMatrixDisplay(cm)
c_mat.plot()""")



print("""import pandas as pd

air_quality_df = pd.read_csv('City_Air_Quality.csv')
air_quality_df.head()

air_quality_df[air_quality_df['AQI']>500]


air_quality_df.isna().sum()

air_quality_df['Date'] = pd.to_datetime(air_quality_df['Date'])

columns = air_quality_df.columns[2:15]
columns

for col in columns:

    air_quality_df[col].fillna(air_quality_df[col].mean(),inplace=True)

import seaborn as sns
import matplotlib.pyplot as plt

ah_df = air_quality_df[air_quality_df['City']=='Ahmedabad']

result = ah_df.groupby('Date')['AQI'].first()

plt.figure(figsize=(20,8))
plt.plot(result.index,result.values)


ah_df = air_quality_df[air_quality_df['City']=='Delhi']

result = ah_df.groupby('Date')['AQI'].first()

plt.figure(figsize=(20,8))
plt.plot(result.index,result.values)

ah_df = air_quality_df[air_quality_df['City']=='Delhi']

result = ah_df.groupby('Date')['PM10'].first()

plt.figure(figsize=(20,8))
plt.plot(result.index,result.values)



ah_df = air_quality_df[air_quality_df['City']=='Delhi']

result = ah_df.groupby('Date')['PM2.5'].first()

plt.figure(figsize=(20,8))
plt.plot(result.index,result.values)

sns.boxplot(air_quality_df[['PM2.5','PM10','NO2']])

plt.show()

sns.scatterplot(air_quality_df,x='AQI',y='PM10',label='PM10',color='red')
sns.scatterplot(air_quality_df,x='AQI',y='PM2.5',label='PM2.5',color='green')

plt.legend()
plt.show()""")







print("""import pandas as pd
import matplotlib.pyplot as plt

retail_df = pd.read_csv('customer_shopping_data.csv')
retail_df.head()

retail_df.isna().sum()
retail_df.shape

retail_df['total_sale'] = retail_df['quantity'] * retail_df['price']
retail_df.head()

sale_by_region = retail_df.groupby('shopping_mall')['total_sale'].sum()
sale_by_region

import seaborn as sns

plt.figure(figsize=(15,6))
sns.barplot(x = sale_by_region.index,y=sale_by_region.sort_values().values)
plt.ylabel('sales')

sales = retail_df.groupby(['shopping_mall','category'])['total_sale'].first()

sales_df = sales.reset_index()

plt.figure(figsize=(13,6))
sns.barplot(x=sales_df['shopping_mall'],y=sales_df['total_sale'],hue=sales_df['category'])
plt.show()""")




print("""import pandas as pd
import matplotlib.pyplot as plt
from sklearn.cluster import KMeans
from sklearn.preprocessing import StandardScaler

iris_df = pd.read_csv('Iris.csv')
iris_df.head()

X = iris_df.drop(columns=['Id','Species'])
X

columns = X.columns
columns

def remove_outliers(df,columns):

    for col in columns:
        q1 = df[col].quantile(0.25)
        q3 = df[col].quantile(0.75)

        iqr = q3 - q1

        lower_bound = q1 - 1.5 * iqr
        upper_bound = q3 + 1.5 * iqr

        fil_df = df[(df[col] >= lower_bound) & (df[col] <= upper_bound)]

    return fil_df

filtered_df = remove_outliers(X,columns)
filtered_df

scaler = StandardScaler()
X_scaled = scaler.fit_transform(X)
X_scaled[:2]
wcss = []

for i in range(1,11):
    kmeans = KMeans(n_clusters=i)
    kmeans.fit(X_scaled)
    wcss.append(kmeans.inertia_)

plt.plot(wcss,marker='o')
plt.xlabel('number of clusters')
plt.show()

best_kmeans = KMeans(n_clusters=4)
clusters = best_kmeans.fit_predict(X_scaled)
X['cluster_labels'] = clusters

import seaborn as sns
plt.figure(figsize=(8, 5))
sns.scatterplot(x=X_scaled[:, 0], y=X_scaled[:, 1], hue=X['cluster_labels'],palette='Set1',s=100)
plt.title('K-Means Clustering on Iris Dataset')
plt.xlabel('sepal length')
plt.ylabel('sepal width')
plt.legend()
plt.show()""")



print("""import pandas as pd
diabetes_df = pd.read_csv('diabetes.csv')
diabetes_df.head()

columns = diabetes_df.columns
columns
def univ_analysis(df,columns):

    results = {}

    for col in columns:
        mean = df[col].mean()
        median = df[col].median()
        mode = df[col].mean()
        variance = df[col].var()
        std_dev = df[col].std()
        skewness = df[col].skew()
        kurtosis = df[col].kurtosis()

        results[col] = {'mean':mean,
                        'median':median,
                        'mode':mode,
                        'variance':variance,
                        'standard deviation':std_dev,
                        'skewness':skewness,
                        'kurtosis':kurtosis}
        

    return pd.DataFrame(results)

univ_analysis(diabetes_df,columns)

diabetes_df.info()
columns = columns[:-1]

def remove_outliers(df,columns):

    for col in columns:
        q1 = df[col].quantile(0.25)
        q3 = df[col].quantile(0.75)

        iqr = q3 - q1

        lower_bound = q1 - 1.5 * iqr
        upper_bound = q3 + 1.5 * iqr

        fil_df = df[(df[col] >= lower_bound) & (df[col] <= upper_bound)]

    return fil_df
filtered_df = remove_outliers(diabetes_df,columns)
filtered_df.shape
from sklearn.model_selection import train_test_split
from sklearn.preprocessing import StandardScaler
from sklearn.linear_model import LinearRegression,LogisticRegression
from sklearn.metrics import mean_absolute_error,r2_score,accuracy_score

X = filtered_df.drop(columns='Outcome')
y = filtered_df['Outcome']
scaler = StandardScaler()
X_scaled = scaler.fit_transform(X)

X_train,X_test,y_train,y_test = train_test_split(X,y,test_size=0.3)
linear_model = LinearRegression()
linear_model.fit(X_train,y_train)

y_pred = linear_model.predict(X_test)

mean_absolute_error(y_test,y_pred), r2_score(y_test,y_pred)


log_model = LogisticRegression(max_iter=300)
log_model.fit(X_train,y_train)

y_pred = log_model.predict(X_test)

accuracy_score(y_test,y_pred)
import seaborn as sns
import matplotlib.pyplot as plt

corr_matrix = diabetes_df.corr()

plt.figure(figsize=(10,8))
sns.heatmap(corr_matrix,annot=True)
plt.show()""")



print("""import pandas as pd
from sklearn_extra.cluster import KMedoids
import matplotlib.pyplot as plt


credit_df = pd.read_csv('CC GENERAL.csv')
credit_df.head()

credit_df.drop(columns='CUST_ID',inplace=True)

credit_df.describe()
credit_df.isna().sum()

credit_df['MINIMUM_PAYMENTS'].fillna(credit_df['MINIMUM_PAYMENTS'].mean(),inplace=True)
credit_df.dropna(inplace=True)
credit_df.shape

columns = credit_df.columns
columns

def remove_outliers(df,columns):

    for col in columns:
        q1 = df[col].quantile(0.25)
        q3 = df[col].quantile(0.75)

        iqr = q3 - q1

        lower_bound = q1 - 1.5 * iqr
        upper_bound = q3 + 1.5 * iqr

        fil_df = df[(df[col] >= lower_bound) & (df[col] <= upper_bound)]

    return fil_df

filtered_df = remove_outliers(credit_df,columns)
filtered_df.shape

from sklearn.preprocessing import StandardScaler
scaler = StandardScaler()
X_scaled = scaler.fit_transform(filtered_df)


from sklearn.metrics import silhouette_score
sil_scores = []

k = range(2,11)

for i in k :
    kmedoids = KMedoids(n_clusters=i)
    cluster_labels = kmedoids.fit_predict(X_scaled)

    score = silhouette_score(X_scaled,cluster_labels)

    sil_scores.append(score)

plt.plot(k,sil_scores,marker='o')

best_kmeoids = KMedoids(n_clusters=2)
clusters = best_kmeoids.fit_predict(X_scaled)

filtered_df['clusters'] = clusters

import seaborn as sns
sns.scatterplot(x=X_scaled[:,0],y=X_scaled[:,-1],hue=filtered_df['clusters'])""")



print("""import pandas as pd
from sklearn.preprocessing import StandardScaler

social_df = pd.read_csv('Social_Network_Ads.csv')

social_df.drop(columns='User ID',inplace=True)
social_df.head()

classes = ['Male','Female']
labels = [0,1]

social_df['Gender'].replace(classes,labels,inplace=True)
social_df.head()

import seaborn as sns
plt.figure(figsize=(10,6))
plt.subplot(1,2,1)
sns.boxplot(social_df['Age'])

plt.subplot(1,2,2)
sns.boxplot(social_df['EstimatedSalary'])

X = social_df.drop(columns='Purchased')
y = social_df['Purchased']

scaler = StandardScaler()

X_scaled = scaler.fit_transform(X)

from sklearn.model_selection import train_test_split,GridSearchCV
from sklearn.neighbors import KNeighborsClassifier
from sklearn.metrics import confusion_matrix,ConfusionMatrixDisplay,precision_score,recall_score

X_train,X_test,y_train,y_test = train_test_split(X_scaled,y,test_size=0.3)

param_grid = {
    'n_neighbors': range(1, 20),
    'metric': ['euclidean', 'manhattan']
}

knn = KNeighborsClassifier()
grid_search = GridSearchCV(knn,param_grid,cv=5)

grid_search.fit(X_train,y_train)

best_knn = grid_search.best_estimator_

y_pred = best_knn.predict(X_test)

acc = accuracy_score(y_test,y_pred)

print(acc)
print(1-acc)
precision_score(y_test,y_pred) , recall_score(y_test,y_pred)

cm = confusion_matrix(y_test,y_pred)
c_mat = ConfusionMatrixDisplay(cm)
c_mat.plot()""")





print("""import requests
import pandas as pd

lat = 19.0211
lon = 72.5134

api_key = "14b01e724014c68826132595f1214a55"
api_url = f"http://api.openweathermap.org/data/2.5/forecast?lat={lat}&lon={lon}&appid={api_key}"

response = requests.get(api_url)
weather_data = response.json()
weather_data

temperature =  [item['main']['temp'] for item in weather_data['list']]
temperature[-1]

humidity =  [item['main']['humidity'] for item in weather_data['list']]
humidity[-1]

wind_speed = [item['wind']['speed'] for item in weather_data['list']]
wind_speed[-1]

weather_desc = [item['weather'][0]['description'] for item in weather_data['list']]
weather_desc[-1]

date_time = [item['dt_txt'] for item in weather_data['list']]
date_time[-1]

weather_df = pd.DataFrame({'date_time':date_time,
                          'temperature':temperature,
                          'humidity':humidity,
                          'wind_speed':wind_speed,
                          'weather_description':weather_desc})


weather_df.head()


weather_df['date_time'] = pd.to_datetime(weather_df['date_time'])
weather_df['date'] = weather_df['date_time'].dt.date

import matplotlib.pyplot as plt
import seaborn as sns

sns.lineplot(weather_df,x='date_time',y='temperature',label='temp')
sns.lineplot(weather_df,x='date_time',y='wind_speed',label='wind speed')
sns.lineplot(weather_df,x='date_time',y='humidity',label='humidity')
plt.legend()
plt.show()

print(weather_df['temperature'].mean())
weather_df['temperature'].max(),weather_df['temperature'].min()

sns.scatterplot(x=weather_df['temperature'],y=weather_df['humidity'])

weather_df.set_index(weather_df['date_time'],inplace=True)

daily_mean_temp = weather_df['temperature'].resample('D').mean()
daily_mean_humidity = weather_df['humidity'].resample('D').mean()
daily_mean_wind_speed = weather_df['wind_speed'].resample('D').mean()

daily_mean_temp.plot(marker='o')""")





print("""import pandas as pd

real_estate_df = pd.read_csv('Bengaluru_House_Data.csv')
real_estate_df.head()

columns = real_estate_df.columns
columns

real_estate_df.isna().sum()

real_estate_df.drop(columns='society',inplace=True)

cols = ['balcony','bath']
for col in cols:
    real_estate_df[col] = real_estate_df[col].fillna(real_estate_df[col].mean())

real_estate_df.dropna(inplace=True)
real_estate_df.shape

real_estate_df['area_type'].unique()


filtered_df = real_estate_df[(real_estate_df['area_type']=='Super built-up  Area') & (real_estate_df['availability']=='Ready To Move')]

real_estate_df['area_type'].unique()

real_estate_df['availability'].unique()

real_estate_df['size'].unique()

for i,value in enumerate(real_estate_df['total_sqft']):
    tokens = str(value).split('-')

    if len(tokens) == 2:

        val = (float(tokens[0]) + float(tokens[1])) / 2
        real_estate_df['total_sqft'].replace(value,int(val),inplace=True)


    if 'Sq. Meter' in str(value):

        index = str(value).find('Sq. Meter')
        val = value[:index]
        val = float(val)*10.7
        real_estate_df['total_sqft'].replace(value,int(val),inplace=True)

    if 'Sq. Yards' in str(value):

        index = str(value).find('Sq. Yards')
        val = value[:index]
        val = float(val)*9
        real_estate_df['total_sqft'].replace(value,int(val),inplace=True)

#Sq. Meter
#Sq. Yards

for i in real_estate_df['total_sqft']:
    if len(str(i)) > 7:
        print(i)

unwanted_units = ['Perch', 'Acres', 'Guntha', 'Cents', 'Grounds']


for i,value in real_estate_df['total_sqft'].items():

    if any(unit in str(value) for unit in unwanted_units):
        real_estate_df.drop(index=i,inplace=True)


real_estate_df.reset_index(drop=True,inplace=True)

real_estate_df['total_sqft'] = pd.to_numeric(real_estate_df['total_sqft'])

real_estate_df.groupby('area_type')['price'].agg(['mean','std'])""")

